@@ -1,6 +1,12 @@
+'''
+Provides the KrakenWsClientCl class to use the Kraken Futures
+websockets.
+'''
+
+import hashlib
+import hmac
+import base64
 from kraken.base_api.base_api import KrakenBaseFuturesAPI
-import logging
-import hashlib, hmac, base64
 
 class FuturesWsClientCl(KrakenBaseFuturesAPI):
     '''This class will be extended in the future if Kraken implements for example
@@ -17,8 +23,8 @@ class FuturesWsClientCl(KrakenBaseFuturesAPI):
         sha256_hash.update(challenge.encode('utf8'))
         return base64.b64encode(
             hmac.new(
-                base64.b64decode(self._secret), 
-                sha256_hash.digest(), 
+                base64.b64decode(self._secret),
+                sha256_hash.digest(),
                 hashlib.sha512
             ).digest()
-        ).decode('utf-8')
\ No newline at end of file
+        ).decode('utf-8')
