@@ -74,7 +74,7 @@ class ConnectSpotWebsocket:
         self.__ws_conn_details = None if not self.__is_auth else self.__client.get_ws_token()
         logging.debug(f'Websocket token: {self.__ws_conn_details}')
 
-        async with websockets.connect(f'wss://{self.__ws_endpoint}', ping_interval=None) as socket:
+        async with websockets.connect(f'wss://{self.__ws_endpoint}', ping_interval=30) as socket:
             logging.info('Websocket connected!')
             self.__socket = socket
 
@@ -144,7 +144,8 @@ class ConnectSpotWebsocket:
             for task in finished:
                 if task.exception():
                     exception_occur = True
-                    message = f'{task} got an exception {task.exception()}\nTRACEBACK: {traceback.format_exc()}'
+                    traceback.print_stack()
+                    message = f'{task} got an exception {task.exception()}\n {task.get_stack()}'
                     logging.warning(message)
                     for process in pending:
                         logging.warning(f'pending {process}')
